Processor.App.ArticleUtils.article\_extractor.ArticleExtractor.check\_required
==============================================================================

.. currentmodule:: Processor.App.ArticleUtils.article_extractor

.. automethod:: ArticleExtractor.check_required